@@ -1,2 +1,2 @@
-from .crypt import read_or_create_key
+from .crypt import read_or_create_key, make_key_from_password
 from .crypt_dir import clean_encrypted_dir, update_encrypted_dir, restore_encrypted_dir
